@@ -335,7 +335,7 @@ def get_config_directory():
 
     """
     # avoid circular import
-    from .commands.stacker import Stacker
+    from .commands.stacker import Stacker  # pylint: disable=import-outside-toplevel
     deprecation_msg = ('get_config_directory has been deprecated and will be '
                        'removed in the next major release')
     warnings.warn(deprecation_msg, DeprecationWarning)
@@ -715,7 +715,7 @@ class SourceProcessor(object):
         """
         # only loading git here when needed to avoid load errors on systems
         # without git installed
-        from git import Repo
+        from git import Repo  # pylint: disable=import-outside-toplevel
 
         ref = self.determine_git_ref(config)
         dir_name = self.sanitize_git_path(uri=config['uri'], ref=ref)
