@@ -87,17 +87,22 @@ def use_npm_ci(path):
 def run_npm_install(path, options, context):
     """Run npm install/ci."""
     # Use npm ci if available (npm v5.7+)
+    cmd = [NPM_BIN, '<place-holder>']
+    if context.no_color:
+        cmd.append('--no-color')
     if options.get('options', {}).get('skip_npm_ci'):
         LOGGER.info("Skipping npm ci or npm install on %s...",
                     os.path.basename(path))
-    elif context.env_vars.get('CI') and use_npm_ci(path):
+        return
+    if context.env_vars.get('CI') and use_npm_ci(path):
         LOGGER.info("Running npm ci on %s...",
                     os.path.basename(path))
-        subprocess.check_call([NPM_BIN, 'ci'])
+        cmd[1] = 'ci'
     else:
         LOGGER.info("Running npm install on %s...",
                     os.path.basename(path))
-        subprocess.check_call([NPM_BIN, 'install'])
+        cmd[1] = 'install'
+    subprocess.check_call(cmd)
 
 
 def warn_on_boto_env_vars(env_vars):
@@ -142,6 +147,18 @@ class RunwayModule(object):
         raise NotImplementedError('You must implement the destroy() method '
                                   'yourself!')
 
+    def __getitem__(self, key):
+        """Make the object subscriptable.
+
+        Args:
+            key (str): Attribute to get.
+
+        Returns:
+            Any
+
+        """
+        return getattr(self, key)
+
 
 class RunwayModuleNpm(RunwayModule):  # pylint: disable=abstract-method
     """Base class for Runway modules that use npm."""
@@ -158,7 +175,6 @@ class RunwayModuleNpm(RunwayModule):  # pylint: disable=abstract-method
                 definition.
 
         """
-        self.check_for_npm()  # fail fast
         options = options or {}
         super(RunwayModuleNpm, self).__init__(context, path, options)
         del self.options  # remove the attr set by the parent class
@@ -169,10 +185,12 @@ class RunwayModuleNpm(RunwayModule):  # pylint: disable=abstract-method
         self.options = options.pop('options', {})
         self.parameters = options.pop('parameters', {})
         self.path = path if isinstance(self.path, Path) else Path(self.path)
+        self.name = options.get('name', self.path.name)
 
         for k, v in options.items():
             setattr(self, k, v)
 
+        self.check_for_npm()  # fail fast
         warn_on_boto_env_vars(self.context.env_vars)
 
     def check_for_npm(self):
@@ -180,7 +198,7 @@ class RunwayModuleNpm(RunwayModule):  # pylint: disable=abstract-method
         if not which('npm'):
             LOGGER.error('%s: "npm" not found in path or is not executable; '
                          'please ensure it is installed correctly.',
-                         self.path.name)
+                         self.name)
             sys.exit(1)
 
     def log_npm_command(self, command):
@@ -190,22 +208,27 @@ class RunwayModuleNpm(RunwayModule):  # pylint: disable=abstract-method
             command (List[str]): List that will be passed into a subprocess.
 
         """
-        LOGGER.info('%s: Running "%s"', self.path.name,
+        LOGGER.info('%s: Running "%s"', self.name,
                     format_npm_command_for_logging(command))
 
     def npm_install(self):
         """Run ``npm install``."""
+        cmd = [NPM_BIN, '<place-holder>']
+        if self.context.no_color:
+            cmd.append('--no-color')
         if self.options.get('skip_npm_ci'):
             LOGGER.info("%s: Skipping npm ci and npm install...",
-                        self.path.name)
-        elif self.context.is_noninteractive and use_npm_ci(str(self.path)):
+                        self.name)
+            return
+        if self.context.is_noninteractive and use_npm_ci(str(self.path)):
             LOGGER.info("%s: Running npm ci...",
-                        self.path.name)
-            subprocess.check_call([NPM_BIN, 'ci'])
+                        self.name)
+            cmd[1] = 'ci'
         else:
             LOGGER.info("%s: Running npm install...",
-                        self.path.name)
-            subprocess.check_call([NPM_BIN, 'install'])
+                        self.name)
+            cmd[1] = 'install'
+        subprocess.check_call(cmd)
 
     def package_json_missing(self):
         """Check for the existence for a package.json file in the module.
@@ -216,7 +239,7 @@ class RunwayModuleNpm(RunwayModule):  # pylint: disable=abstract-method
         """
         if not (self.path / 'package.json').is_file():
             LOGGER.warning('%s: Module is missing a "package.json"',
-                           self.path.name)
+                           self.name)
             return True
         return False
 
