@@ -1,19 +1,27 @@
 """Utility functions."""
 from __future__ import print_function
-from typing import Any, Dict, Iterator, List, Optional, Union  # noqa pylint: disable=unused-import
 
-from contextlib import contextmanager
 import hashlib
 import importlib
 import json
+import logging
 import os
 import platform
 import re
 import stat
-from subprocess import check_call
 import sys
+from contextlib import contextmanager
+from subprocess import check_call
+from typing import (Any, Dict, Iterator,  # noqa pylint: disable=unused-import
+                    List, Optional, Union)
+
 import six
 
+if sys.version_info >= (3, 6):
+    from contextlib import AbstractContextManager  # pylint: disable=E
+else:
+    AbstractContextManager = object
+
 AWS_ENV_VARS = ('AWS_ACCESS_KEY_ID', 'AWS_SECRET_ACCESS_KEY',
                 'AWS_SESSION_TOKEN')
 EMBEDDED_LIB_PATH = os.path.join(
@@ -281,6 +289,96 @@ class MutableMap(six.moves.collections_abc.MutableMapping):  # pylint: disable=n
         return json.dumps(self.data)
 
 
+class SafeHaven(AbstractContextManager):
+    """Context manager that caches and resets important values on exit.
+
+    Caches and resets os.environ, sys.argv, sys.modules, and sys.path.
+
+    """
+
+    # pylint: disable=redefined-outer-name
+    def __init__(self, argv=None, environ=None, sys_modules_exclude=None,
+                 sys_path=None):
+        """Instantiate class.
+
+        Args:
+            argv (Optional[List[str]]): Override the value of sys.argv.
+            environ (Optional[Dict[str, str]]): Update os.environ.
+            sys_modules_exclude (Optional[List[str]]): A list of modules to
+                exclude when reverting sys.modules to its previous state.
+                These are checked as ``module.startswith(name)``.
+            sys_path (Optional[List[str]]): Override the value of sys.path.
+
+        """
+        self.__os_environ = dict(os.environ)
+        self.__sys_argv = list(sys.argv)
+        # deepcopy can't pickle sys.modules and dict()/.copy() are not safe
+        # pylint: disable=unnecessary-comprehension
+        self.__sys_modules = {k: v for k, v in sys.modules.items()}
+        self.__sys_path = list(sys.path)
+        # more informative origin for log statements
+        self.log = logging.getLogger('runway.' + self.__class__.__name__)
+        self.sys_modules_exclude = sys_modules_exclude or []
+
+        if isinstance(argv, list):
+            sys.argv = argv
+        if isinstance(environ, dict):
+            os.environ.update(environ)
+        if isinstance(sys_path, list):
+            sys.path = sys_path
+
+    def reset_all(self):
+        """Reset all values cached by this context manager."""
+        self.log.debug('resetting all managed values...')
+        self.reset_os_environ()
+        self.reset_sys_argv()
+        self.reset_sys_modules()
+        self.reset_sys_path()
+
+    def reset_os_environ(self):
+        """Reset the value of os.environ."""
+        self.log.debug('resetting os.environ: %s', self.__os_environ)
+        os.environ.clear()
+        os.environ.update(self.__os_environ)
+
+    def reset_sys_argv(self):
+        """Reset the value of sys.argv."""
+        self.log.debug('resetting sys.argv: %s', self.__sys_argv)
+        sys.argv = self.__sys_argv
+
+    def reset_sys_modules(self):
+        """Reset the value of sys.modules."""
+        self.log.debug('resetting sys.modules: %s', self.__sys_modules)
+        # sys.modules can be manipulated to force reloading modules but,
+        # replacing it outright does not work as expected
+        for module in list(sys.modules.keys()):
+            if module not in self.__sys_modules and \
+                    not any(module.startswith(n)
+                            for n in self.sys_modules_exclude):
+                self.log.debug('removed sys.module: {"%s": "%s"}', module,
+                               sys.modules.pop(module))
+
+    def reset_sys_path(self):
+        """Reset the value of sys.path."""
+        self.log.debug('resetting sys.path: %s', self.__sys_path)
+        sys.path = self.__sys_path
+
+    def __enter__(self):
+        """Enter the context manager.
+
+        Returns:
+            SafeHaven: Instance of the context manager.
+
+        """
+        self.log.debug('entering a safe haven...')
+        return self
+
+    def __exit__(self, exc_type, exc_value, traceback):
+        """Exit the context manager."""
+        self.log.debug('leaving the safe haven...')
+        self.reset_all()
+
+
 @contextmanager
 def argv(*args):
     # type: (str) -> None
@@ -330,18 +428,15 @@ def environ(env=None, **kwargs):
     env = env or {}
     env.update(kwargs)
 
-    original_env = {key: os.getenv(key) for key in env}
+    original_env = dict(os.environ)
     os.environ.update(env)
 
     try:
         yield
     finally:
         # always restore original values
-        for key, val in original_env.items():
-            if val is None:
-                os.environ.pop(key, None)  # handle key missing
-            else:
-                os.environ[key] = val
+        os.environ.clear()
+        os.environ.update(original_env)
 
 
 def load_object_from_string(fqcn, try_reload=False):
